@@ -1,11 +1,35 @@
-    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements            com.apple.cs.CodeRequirements-1    4  #  com.apple.cs.CodeSignature              t   4                     Ajulia-config A427R7F42H L
-0t<                    ;'v=17@                  H    ,            
+    Mac OS X            	   2  *p     *                                      ATTR      *  L  )V                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     Ajulia-config A427R7F42H !R3~v1                                        L
+0t<                    J*;%-<# qq  <?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+	<key>com.apple.security.automation.apple-events</key>
+	<true/>
+	<key>com.apple.security.get-task-allow</key>
+	<true/>
+	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
+	<true/>
+	<key>com.apple.security.cs.allow-jit</key>
+	<true/>
+	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
+	<true/>
+	<key>com.apple.security.cs.debugger</key>
+	<true/>
+	<key>com.apple.security.cs.disable-library-validation</key>
+	<true/>
+	<key>com.apple.security.device.audio-input</key>
+	<true/>
+	<key>com.apple.security.device.camera</key>
+	<true/>
+</dict>
+</plist>
+                  H    ,            
 com.apple.env                      julia-config                  
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H                4                      Ajulia-config A427R7F42H |ZЂx\lLV~cpKY7,C0                                sib*\<AzuJccρ0	*H
+A427R7F42H               4                      Ajulia-config A427R7F42H ONvHl_Zt+5b4UEhY2                                                                |ZЂx\lLV~cpKY7,C0                                g]Fq`u.E\&F)Y'	0	*H
 010
 	`He 0	*H
   0>0& ?͗Iz˃Mxs]C0
@@ -83,50 +107,48 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-260208015443Z0/	*H
-	1" rg@/׸Ga.釗0[	*Hcd	1N0+<2c`uTiSj^K0-	`He 0Y4%kO?+f`獤B0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+251007183158Z0/	*H
+	1" R=^MaX3 R#9Pb\3<0[	*Hcd	1N0+Lyb5'֤ %0-	`He U>`O:gr_pVxTp!0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		PDJj4fG5YHWZVN5pj1NqXooaSwM=
+		2Ex5YqvS8zX9urSNJ7G7oNakICU=
 		</data>
 		<data>
-		MFmZNMvtiCW03GtPPyuWD2b70Nc=
+		/f5V8z5gDE8aOmdyBp5fn72D9HA=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  ]@cxN,ܔ
-UyD`vSQ/Bx3:89'm5!|,<SWǨxȻ/'NfMk A[b89{)3II']*hv(<- h;Wِ!s2@LLRRb$kDZQk4xsoPۋSL%&*TJ<yQ58c{f_Mo3fBB>qPiVr:[5B5%0*H
+  "éiAX䄥{@Г6z<?mmMGV1"gt;@q.mBwݡ_QB_sJ"1FHNVfNlLNr0_6g%AtS)+9-pto}+$usrя:w|pȦ#=t. 1Z
+Zf<NgQS6)92/pPϩ	Z@gsYwm.W&Si	sYĎ;O諄ھ6zD0*H
 	10	*H
-010	+ 0z*H
-	ki0g*010
-	`He  @!sHf<6XrjpL20260208015444Z0jSZeO
-00z*y#0
+010	+ 0{*H
+	lj0h*010
+	`He  ՙyFf&#Ɯ/{ן`7-&20251007183158Z0	 O{-
+00*?0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-260202174540Z
-260316174539Z0A10UTimestamp Signer MA210U
+250915174020Z
+251027174019Z0A10UTimestamp Signer MA110U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- hiGH3FfMUd X|tKHZrW4p+jI%:Z9߽Aa4_+=өvp<ygi{ACeiES`Ž00t;̊Q1	CĪ949PVXY#FM^/Sd7/P
-jR;(NvsCB{>qʅIDѬ	a{WW~ʚ
-XXM=21K:|0/X7SGc1 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uci)WsS
-Zi}0U0
+ DJs5<m0-@HtDf^i=Br-])w{_ Gև֩8\b~ptw{uN
+- 1W!;<B+FUk'J)ּPҊE|zsЧB:M`_M}.Ź
+^˶=1_J%#Xs'UTIjeC8+"J͠7G 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0UKmc6t+;ƇN0U0
 	*H
-  ibmڣpŗb]]힆mR5	`4C?T ;NC[p^H63$,&r9krTXCc.'\,?ˇs#)*lLɌ->U	(ѱU"@XѪ^|Lt|YڞFu#tr$192V?KИe<c9
-ٚ٫Edlw,Z/SÝa
-%tne3EFȍ_v@Q @Ffl00}LWc0
+  'MoRRMre嫕-{O0
+ʐDP\绮Ym6֏m>\'qy7	yTa =_4hg~`om(et,$)yD VQ!ElZ92}=Ta!< SZHF;UM'iª덡s十G>+ o6iRjTYG>:L-Og5e00}LWc0
 	*H
  0b10	UUS10U
 
@@ -167,19 +189,14 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUSz*y#0	+ 0	*H
+Apple Inc.10	UUS*?0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-260208015444Z0#	*H
-	1+jy]Kx0+*H
-	1000
-cl_B@uLo0
+251007183158Z0#	*H
+	13?>-ozfdnlG0+*H
+	1000`|28bVJ+ێ87䭉0
 	*H
-  g7,ᤅs=Ч8yFSlymKG8niaT΃0#/
-VaLEsDwݣ;
- *T%A9y 
-?gpDj=ri
-_'1Ll__ked<\'msWžSs&wG`D1
-LeuP~?C`tWyFLlxެYC.hwWuNp!ZgtGr/P(      
\ No newline at end of file
+  )G&_Xq'TgoCĠ;酭*^	o8{gV4U9	k:*^N4>&pM-DXzM,]icٛp/w%D`qlbڳsInуG%&o$V(t~e|\sKdh#.?{EmaF
+N- oJE?h	;~Lxkǯug{Wx~ PT}      
\ No newline at end of file
