@@ -1,9 +1,34 @@
-    Mac OS X            	   2  &{     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      Q      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              q   4        C             >generator A427R7F42H y*-#q0                    V>{ԨԦ                            	generator                     
+    Mac OS X            	   2  *5     *g                                      ATTR      *g  L  )                 L     com.apple.cs.CodeDirectory     
+    com.apple.cs.CodeEntitlements            com.apple.cs.CodeRequirements        	   com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     >generator A427R7F42H !R3~v1                                        y*-#q0                    MKxӧ!axqq  <?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+	<key>com.apple.security.automation.apple-events</key>
+	<true/>
+	<key>com.apple.security.get-task-allow</key>
+	<true/>
+	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
+	<true/>
+	<key>com.apple.security.cs.allow-jit</key>
+	<true/>
+	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
+	<true/>
+	<key>com.apple.security.cs.debugger</key>
+	<true/>
+	<key>com.apple.security.cs.disable-library-validation</key>
+	<true/>
+	<key>com.apple.security.device.audio-input</key>
+	<true/>
+	<key>com.apple.security.device.camera</key>
+	<true/>
+</dict>
+</plist>
+                            	generator                     
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H                4        C              >generator A427R7F42H z|R!A$п44!+*6̊)                                䶈:6RA'Nݼ0	*H
+A427R7F42H    	           4                      >generator A427R7F42H ONvHl_Zt+5b4UEhY2                                                                z|R!A$п44!+*6̊)                                SdL\0Fh]0	*H
 010
 	`He 0	*H
   0>0& ?͗Iz˃Mxs]C0
@@ -81,51 +106,50 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-260208015444Z0/	*H
-	1" ˏE)Jp2.u(a<0[	*Hcd	1N0+Ս;i #nk`nL0-	`He -obl$+y]0%# 0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+251007183158Z0/	*H
+	1" ҫH(iͱVps59t40[	*Hcd	1N0+ℶץw8&ZeXw10-	`He sX@KƒtK3A)Y/Jу0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		1Y0dDjtpAN/8I24M7mvtYMflbkw=
+		8gfihLbXpXcZBTjNJlpl3Fh3AjE=
 		</data>
 		<data>
-		LRHu6m9ibOsk4H+/Fit5sl0w6q8=
+		q3Oh8ljg+Q5AS8aS/3RLM58eBEE=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-   9sEع-	8OQ~dֆ!IK7	6<z^qax`Mdlsf\d
-\2G"MPRؓ!q{U;8FbD[Ozz^šqV]Ij*2xHT4k^M?`
-t%[Gꯐ7za Ճ):Ebxq7'58|	xH	{p^r"r0*H
+  d
+D࿄h#A^(|Wh36vmK!.jY"coScđ,*	^n:BP]! _#DT^'2o]
+
+q? `GSUYY7O#kFpBBH>m(=ARNKNoqIu$m}-эY2*DȜ@a`':SXR@]嫑N-G*y e[0*H
 	10	*H
-010	+ 0{*H
-	lj0h*010
-	`He  ~N1	?	j~yDOՆ9WM"20260208015445Z0	 ?xL͎Š
-00z*y#0
+010	+ 0z*H
+	ki0g*010
+	`He  i6LB:U:qyl7ЭKS+<20251007183158Z0AGX;
+00*?0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-260202174540Z
-260316174539Z0A10UTimestamp Signer MA210U
+250915174020Z
+251027174019Z0A10UTimestamp Signer MA110U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- hiGH3FfMUd X|tKHZrW4p+jI%:Z9߽Aa4_+=өvp<ygi{ACeiES`Ž00t;̊Q1	CĪ949PVXY#FM^/Sd7/P
-jR;(NvsCB{>qʅIDѬ	a{WW~ʚ
-XXM=21K:|0/X7SGc1 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uci)WsS
-Zi}0U0
+ DJs5<m0-@HtDf^i=Br-])w{_ Gև֩8\b~ptw{uN
+- 1W!;<B+FUk'J)ּPҊE|zsЧB:M`_M}.Ź
+^˶=1_J%#Xs'UTIjeC8+"J͠7G 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0UKmc6t+;ƇN0U0
 	*H
-  ibmڣpŗb]]힆mR5	`4C?T ;NC[p^H63$,&r9krTXCc.'\,?ˇs#)*lLɌ->U	(ѱU"@XѪ^|Lt|YڞFu#tr$192V?KИe<c9
-ٚ٫Edlw,Z/SÝa
-%tne3EFȍ_v@Q @Ffl00}LWc0
+  'MoRRMre嫕-{O0
+ʐDP\绮Ym6֏m>\'qy7	yTa =_4hg~`om(et,$)yD VQ!ElZ92}=Ta!< SZHF;UM'iª덡s十G>+ o6iRjTYG>:L-Og5e00}LWc0
 	*H
  0b10	UUS10U
 
@@ -166,17 +190,17 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUSz*y#0	+ 0	*H
+Apple Inc.10	UUS*?0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-260208015445Z0#	*H
-	1M
-fաGqK	R@cw0+*H
-	1000
-cl_B@uLo0
+251007183158Z0#	*H
+	1sɦ ^bCU0+*H
+	1000`|28bVJ+ێ87䭉0
 	*H
-  3Ai<Iq	bH_)~*/cooa#j8%~(W+|vNjb]qQSGtഽ,.1r
-qO`#jo%-A PԔLcǌNf'F˖&?wV6-7#hL#r3lM֝{YԞux:^?S158H٨.F1'[c+DU
-`      
\ No newline at end of file
+  3Xp|>
+_Z	q+p6
+XNl*ט*F 5| 7kS`dm;60!$[ JSĂ"IF:v>iʭ '+gEMRR3pV6OKif/
+DЖȠq?>X'趚O=Xf;ś֋Wl}8@iG9uXoy "EڧF,5-
++|><1|@A3      
\ No newline at end of file
