@@ -1,10 +1,35 @@
-    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements            com.apple.cs.CodeRequirements-1    J  #  com.apple.cs.CodeSignature              {   4                     Hmake-fancy-terminfo A427R7F42H s'CwTv                    /sEk                  H    ,            
+    Mac OS X            	   2  *     *                                      ATTR      *  L  )k                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements      
+     com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     Hmake-fancy-terminfo A427R7F42H !R3~v1                                        s'CwTv                    /sEkqq  <?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+	<key>com.apple.security.automation.apple-events</key>
+	<true/>
+	<key>com.apple.security.get-task-allow</key>
+	<true/>
+	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
+	<true/>
+	<key>com.apple.security.cs.allow-jit</key>
+	<true/>
+	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
+	<true/>
+	<key>com.apple.security.cs.debugger</key>
+	<true/>
+	<key>com.apple.security.cs.disable-library-validation</key>
+	<true/>
+	<key>com.apple.security.device.audio-input</key>
+	<true/>
+	<key>com.apple.security.device.camera</key>
+	<true/>
+</dict>
+</plist>
+                  H    ,            
 com.apple.env                      make-fancy-terminfo                   
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H                4                      Hmake-fancy-terminfo A427R7F42H 5+>ӤY7vm,-y                                 ݆TVTNrqnXzbĀ0	*H
+A427R7F42H               4                      Hmake-fancy-terminfo A427R7F42H ONvHl_Zt+5b4UEhY2                                                                5+>ӤY7vm,-y                                 ݆TVTNrqnXzbĀ0	*H
 010
 	`He 0	*H
   0>0& ?͗Iz˃Mxs]C0
@@ -82,51 +107,51 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-260208015444Z0/	*H
-	1" {cWJjɮWhAF>Dv*	0[	*Hcd	1N0+q7Z.7|0-	`He "%i7%pp+dF
-&/j#vFK0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+251007183158Z0/	*H
+	1" I08li|H<x^[zߡp7HYKu0[	*Hcd	1N0+
+1yrzi\DT0-	`He ߥPdR.)7\1Kj/N4=0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		nHGbDoXNHDdanfW2i6guN/wfBHw=
+		CjF5Dh9yj3qc5Glcp+MIRFTil/I=
 		</data>
 		<data>
-		rCIlaTclcHArmWQGHBpGDSbIL/s=
+		36VQZPxS56XOfy4pNxDTXDFLai8=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  z펥TOZsLP1$JӨd+ADkkwD ui}E07_Z$w]ʑJ&]k_ 9*8XD$
-2.nZז9t%?KV֨xڒ͘3Zf7NE{
-DqAauR1kNGD>Uơ0*H
+  -3	{n
+~ 9;B91<rcET*8JI
+_YLNу8ƿp#aZѴ3A,YUh&+Y5F_<upP;>fc.I[ 0w4n}ဌo4 <aGGzq+@mzy=.~;zhP5u*#S0Rp<f^~ȳ
+!〡0*H
 	10	*H
 010	+ 0z*H
 	ki0g*010
-	`He  )v57No0FuG}Of20260208015445Z0nU??=
-00wZ"C0
+	`He  ~?qwA!B=&xU*q Q!$yT20251007183200Z0pK;gn
+00*?0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-260202174540Z
-260316174539Z0A10UTimestamp Signer MA110U
+250915174020Z
+251027174019Z0A10UTimestamp Signer MA110U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- #6p8̹(B5H^cPGFHZ '@mL@/!c /g
-lZ,Pʹad|-MEGjmsLũ0fheٸ )4_"Fshbrx`˷>OAw֚<P 0X줪 ̷?-M/a*.{,Pu^tzA'Xz۲Vlv@܉a:9 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0U0g,6t`=Eod0U0
+ DJs5<m0-@HtDf^i=Br-])w{_ Gև֩8\b~ptw{uN
+- 1W!;<B+FUk'J)ּPҊE|zsЧB:M`_M}.Ź
+^˶=1_J%#Xs'UTIjeC8+"J͠7G 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0UKmc6t+;ƇN0U0
 	*H
-  +h\`+vq
-(9\9CMvjRu0l c9(O*yd5uTi
-j\CpCŹln*Ja9)GNk2WpՕc_&$!oM_}¯ӵܷ o\(O<'W_9+N˨bc	Ai"TWŐ~w3	1
-@zI(PQLl.JU>00}LWc0
+  'MoRRMre嫕-{O0
+ʐDP\绮Ym6֏m>\'qy7	yTa =_4hg~`om(et,$)yD VQ!ElZ92}=Ta!< SZHF;UM'iª덡s十G>+ o6iRjTYG>:L-Og5e00}LWc0
 	*H
  0b10	UUS10U
 
@@ -167,16 +192,14 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUSwZ"C0	+ 0	*H
+Apple Inc.10	UUS*?0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-260208015445Z0#	*H
-	1cGJT*YPVc^0+*H
-	1000dldzK#G{:R0
+251007183200Z0#	*H
+	12V3թLD0+*H
+	1000`|28bVJ+ێ87䭉0
 	*H
-  B,cZZtZg
-Ḙ^/ZwZ5Oܾ֪<@
- rphbU6:s9QAxH.B<ҦukLrl^7nȥ%&4hfF*'7`257(ͺ[O7̪qݤp=?QΝ#'; T&H_G6D]9-@aIg>&Z#<m]p9w
-      
\ No newline at end of file
+  ?Ltm1hT@,#Dx)&水^e9w;[9X <kx1K9=I3Ee̐\xYXT7>&1]5LDh~Qj	#~gw{GCy:Vaec<LJ9#T8a
+hTUGnU^^,;l[mNik&e`GFôؐ[%@1ԍܾf5GS4a];i      
\ No newline at end of file
